webbpsf\_ext.maths
==================

.. automodule:: webbpsf_ext.maths

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      binned_statistic
      find_closest
      fit_bootstrap
      hist_indices
      jl_poly
      jl_poly_fit
      radial_std
      round_int
   
   

   
   
   

   
   
   



